@@ -1,23 +1,25 @@
 # Copyright (c) 2014 Santiago Barreda
 # All rights reserved.
 
-plot.spectrogram <-function (x, y, ylim, quality = FALSE, ...){
+plot.spectrogram <-function (x, y, ylim,xlim, quality = FALSE, ...){
   if (x$colors[1] == TRUE)
     zcolors = colorRampPalette (c('dark blue','blue','cyan','yellow',
                                   'orange','red', 'brown'))
   if (x$colors[1] == FALSE) zcolors = colorRampPalette (c('white','black'))
   if (length(x$colors) > 1) zcolors = colorRampPalette (x$colors)
   
-  zrange = range(x$spectrogram, finite = TRUE)
+  zrange = c(-x$dynamicrange,0)
   nlevels = abs (zrange[1] - zrange[2]) * 1.2
   
   levels = pretty(zrange, nlevels)
   zcolors = zcolors(length(levels) - 1);
   times = as.numeric(rownames (x$spectrogram))
   hz = as.numeric(colnames (x$spectrogram))
+
+  x$spectrogram[which(x$spectrogram < (-1 * x$dynamicrange))] = -1 * x$dynamicrange
   
-  if (missing (ylim)) ylim = range (0, 5000)
-  if (!exists ("xlim")) xlim = range (times)
+  if (missing (ylim)) ylim = range (0, x$maxfreq)
+  if (missing (xlim)) xlim = range (times)
   
   plot.new()
   if (quality){  
@@ -29,6 +31,7 @@ plot.spectrogram <-function (x, y, ylim, quality = FALSE, ...){
     title(xlab = "Time (ms)", ylab = "Frequency (Hz)")
   }
   if (!quality){
-    image (as.double(times), as.double(hz), x$spectrogram, useRaster = FALSE, col = zcolors, xlab = 'Time (ms)', ylab = "Frequency (Hz)")
+    image (as.double(times), as.double(hz), x$spectrogram, useRaster = FALSE, col = zcolors, xlab = 'Time (ms)', ylab = "Frequency (Hz)", ylim = ylim, xlim = xlim,...)
   }
 }
+
